//#region src/block/CodeBlock.d.ts

/**
* Scrapbox {@link https://scrapbox.io/help/Syntax#58348ae2651ee500008d67df | code block} type
*/
interface CodeBlock {
  indent: number;
  type: "codeBlock";
  fileName: string;
  content: string;
} //#endregion
//#region src/block/node/DecorationNode.d.ts
type DecorationChar = "*" | "!" | "\"" | "#" | "%" | "&" | "'" | "(" | ")" | "+" | "," | "-" | "." | "/" | "{" | "|" | "}" | "<" | ">" | "_" | "~";
type AsteriskDecorationChar = "*-1" | "*-2" | "*-3" | "*-4" | "*-5" | "*-6" | "*-7" | "*-8" | "*-9" | "*-10";
/**
* character type of decoration
*/
type Decoration = Exclude<DecorationChar, "*"> | AsteriskDecorationChar;

//#endregion
//#region src/block/node/type.d.ts
interface BaseNode {
  raw: string;
}
/**
* Scrapbox {@link https://scrapbox.io/help/Syntax#58348ae2651ee500008d67d8 | quote node} type
*/
interface QuoteNode extends BaseNode {
  type: "quote";
  nodes: Node[];
}
/**
* Scrapbox {@link https://scrapbox.io/help-jp/Helpfeel%E8%A8%98%E6%B3%95 | Helpfeel node} type
*/
interface HelpfeelNode extends BaseNode {
  type: "helpfeel";
  text: string;
}
/**
* Scrapbox {@link https://scrapbox.io/help-jp/%E3%81%9D%E3%81%AE%E4%BB%96%E3%81%AE%E6%9B%B8%E3%81%8D%E6%96%B9#5cfa1ea397c291000095c81e | strong image node} type
*/
interface StrongImageNode extends BaseNode {
  type: "strongImage";
  src: string;
}
/**
* Scrapbox {@link https://scrapbox.io/help/Icon#5ec273358ee92a000078cafe | strong icon node} type
*/
interface StrongIconNode extends BaseNode {
  type: "strongIcon";
  pathType: "root" | "relative";
  path: string;
}
/**
* Scrapbox {@link https://scrapbox.io/help/Syntax#58348ae2651ee500008d67cb | strong node} type
*/
interface StrongNode extends BaseNode {
  type: "strong";
  nodes: Node[];
}
/**
* Scrapbox {@link https://scrapbox.io/help/Syntax#5e7c7a17651ee50000d77b2e | formula node} type
*/
interface FormulaNode extends BaseNode {
  type: "formula";
  formula: string;
}
/**
* Scrapbox {@link https://scrapbox.io/help/Syntax#58348ae2651ee500008d67cc | decoration node} type
*/
interface DecorationNode extends BaseNode {
  type: "decoration";
  rawDecos: string;
  decos: Decoration[];
  nodes: Node[];
}
/**
* Scrapbox {@link https://scrapbox.io/help/Syntax#58348ae2651ee500008d67db | code node} type
*/
interface CodeNode extends BaseNode {
  type: "code";
  text: string;
}
/**
* Scrapbox {@link https://scrapbox.io/help/Code_notation#587d557d651ee50000dc693d | command line node} type
*/
interface CommandLineNode extends BaseNode {
  type: "commandLine";
  symbol: string;
  text: string;
}
/**
* Scrapbox blank node type
*/
interface BlankNode extends BaseNode {
  type: "blank";
  text: string;
}
/**
* Scrapbox {@link https://scrapbox.io/help/Syntax#58348ae2651ee500008d67b8 | image node} type
*/
interface ImageNode extends BaseNode {
  type: "image";
  src: string;
  link: string;
}
/**
* Scrapbox {@link https://scrapbox.io/help/Link | link node} type
*/
interface LinkNode extends BaseNode {
  type: "link";
  pathType: "absolute" | "root" | "relative";
  href: string;
  content: string;
}
/**
* Scrapbox {@link https://scrapbox.io/help-jp/Location%E8%A8%98%E6%B3%95 | Google Map node} type
*/
interface GoogleMapNode extends BaseNode {
  type: "googleMap";
  latitude: number;
  longitude: number;
  zoom: number;
  place: string;
  url: string;
}
/**
* Scrapbox {@link https://scrapbox.io/help/Syntax#58348ae2651ee500008d67c7 | icon node} type
*/
interface IconNode extends BaseNode {
  type: "icon";
  pathType: "root" | "relative";
  path: string;
}
/**
* Scrapbox {@link https://scrapbox.io/help/Syntax#58348ae2651ee500008d67d5 | hash tag node} type
*/
interface HashTagNode extends BaseNode {
  type: "hashTag";
  href: string;
}
/**
* Scrapbox number list node type
*/
interface NumberListNode extends BaseNode {
  type: "numberList";
  rawNumber: string;
  number: number;
  nodes: Node[];
}
/**
* Scrapbox plain node type
*/
interface PlainNode extends BaseNode {
  type: "plain";
  text: string;
}
/**
* Scrapbox node type
*/
type Node = QuoteNode | HelpfeelNode | StrongImageNode | StrongIconNode | StrongNode | FormulaNode | DecorationNode | CodeNode | CommandLineNode | BlankNode | ImageNode | LinkNode | GoogleMapNode | IconNode | HashTagNode | NumberListNode | PlainNode; //#endregion
//#region src/block/Line.d.ts
/**
* Scrapbox line type
*/
interface Line {
  indent: number;
  type: "line";
  nodes: Node[];
}

//#endregion
//#region src/block/Table.d.ts
/**
* Scrapbox {@link https://scrapbox.io/help/Syntax#58795996651ee5000012d4c7 | table} type
*/
interface Table {
  indent: number;
  type: "table";
  fileName: string;
  cells: Node[][][];
}

//#endregion
//#region src/block/Title.d.ts
/**
* Scrapbox title type
*/
interface Title {
  type: "title";
  text: string;
}

//#endregion
//#region src/block/index.d.ts
/**
* Scrapbox block type
*/
type Block = Title | CodeBlock | Table | Line;

//#endregion
//#region src/parse.d.ts
/**
* parser option type
*/
interface ParserOption {
  /**
  * is Scrapbox notation text including title
  */
  hasTitle?: boolean;
}
/**
* Scrapbox page type
*/
type Page = Block[];
/**
* parse Scrapbox notation text into JavaScript Object
* @param input raw Scrapbox notation text
* @param opts parser options
* @returns syntax tree of parsed input
*/
declare const parse: (input: string, opts?: ParserOption) => Page;
/**
* get title of Scrapbox page
* @param input raw Scrapbox notation text
* @returns title of input Scrapbox page
*/
declare const getTitle: (input: string) => string;

//#endregion
export { BlankNode, Block, CodeBlock, CodeNode, CommandLineNode, Decoration, DecorationNode, FormulaNode, GoogleMapNode, HashTagNode, HelpfeelNode, IconNode, ImageNode, Line, LinkNode, Node, Page, ParserOption, PlainNode, QuoteNode, StrongIconNode, StrongImageNode, StrongNode, Table, Title, getTitle, parse };
//# sourceMappingURL=index.d.ts.map